'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-2a6e6244.js');
const store = require('./store-fe3d3434.js');
const index_esm_min = require('./index.esm.min-83391a19.js');

const bpSdkApplicationLoadCss = "";

let BpSdkApplicationLoad = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-application-load');
    customElements.whenDefined('bp-sdk-external-application-load').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return index.h("bp-sdk-external-application-load", null);
  }
  renderInternal() {
    return (index.h("div", { class: "bp-sdk-application-load__container" }, index.h("bp-sdk-spinner", null)));
  }
};
BpSdkApplicationLoad.style = bpSdkApplicationLoadCss;

const bpSdkDriverQuestionSetContainerCss = "";

let BpSdkDriverQuestionSetContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Mapped question groups
     */
    this.questionGroupsWithAnswersAsKey = new Map();
    /**
     * Driver count limit
     */
    this.driverLimit = 20;
    this.useExternal = false;
    this.handleSubscriptions = () => {
      if (store.canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        errors: state.application.errors,
        driverLimit: state.config.options.driverLimit,
      };
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-question-set-container');
    customElements.whenDefined('bp-sdk-external-driver-question-set-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-driver-question-set-container", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, driverLimit: this.driverLimit, errors: this.errors, locked: this.locked, questionSet: this.questionSet, saveHandler: this.saveHandler, questionGroupsWithAnswersAsKey: this.questionGroupsWithAnswersAsKey }));
  }
  renderInternal() {
    return (index.h("bp-sdk-driver-question-set", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, errors: this.errors, locked: this.locked, maxDrivers: this.driverLimit, questionSet: this.questionSet, saveHandler: this.saveHandler, questionGroupsWithAnswersAsKey: this.questionGroupsWithAnswersAsKey }));
  }
  get el() { return index.getElement(this); }
};
BpSdkDriverQuestionSetContainer.style = bpSdkDriverQuestionSetContainerCss;

const bpSdkPendingProcessContainerCss = "";

let BpSdkPendingProcessContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.pendingProcesses = [];
    this.useExternal = false;
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-pending-process-container');
    customElements.whenDefined('bp-sdk-external-pending-process-container').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return index.h("bp-sdk-external-pending-process-container", { pendingProcesses: this.pendingProcesses });
  }
  renderInternal() {
    return index.h("div", { class: "bp-sdk-pending-process-container__container" }, index.h("bp-sdk-pending-process", { pendingProcesses: this.pendingProcesses }));
  }
};
BpSdkPendingProcessContainer.style = bpSdkPendingProcessContainerCss;

let BpSdkQuestionSet = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Can Save
     */
    this.canSave = true;
    /**
     * A Map of nested question groups for rendering nested question groups/question pools
     */
    this.questionGroupsWithAnswersAsKey = new Map();
    this.useExternal = false;
    this.questionGroups = {};
    this.parentIds = [];
    this.answers = [];
    this._answers = [];
    this.preventRefresh = (e) => {
      e.preventDefault();
      return false;
    };
  }
  onQuestionSetChange(questionSet) {
    var _a;
    this.questionGroups = index_esm_min.V9(questionSet, this.questionGroups);
    this.parentIds = index_esm_min.B9(this.questionGroups);
    const questionSetAnswers = (_a = questionSet === null || questionSet === void 0 ? void 0 : questionSet.answers) !== null && _a !== void 0 ? _a : [];
    this.answers = questionSetAnswers;
  }
  onAnswersChange(answers) {
    this._answers = index_esm_min.k9(answers, this.deletedPool);
  }
  onDeletedPoolChange(poolId) {
    this._answers = index_esm_min.k9(this.answers, poolId);
  }
  onSaveQuestionSet() {
    this.saveHandler(this.questionSet);
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-set');
    customElements.whenDefined('bp-sdk-external-question-set').then(() => {
      this.useExternal = true;
    });
    this.onQuestionSetChange(this.questionSet);
  }
  inQuestionGroup(answer) {
    return this.questionSet.question_set.question_groups.some((qg) => {
      return qg.question_ids.some((id) => id === answer.question.id);
    });
  }
  getAnswerPool(parentGroupId, poolId = '') {
    var _a, _b;
    const groupMap = (_a = this.questionGroups[poolId]) !== null && _a !== void 0 ? _a : {};
    return (_b = groupMap[parentGroupId]) !== null && _b !== void 0 ? _b : { answers: [] };
  }
  onDeletePool({ detail }) {
    this.deletedPool = detail;
  }
  render() {
    return (index.h("div", { class: "bp-sdk-question-set" }, this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()));
  }
  renderExternal() {
    return (index.h("bp-sdk-external-question-set", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, locked: this.locked, questionSet: this.questionSet, saveHandler: this.saveHandler, questionGroupsWithAnswersAsKey: this.questionGroupsWithAnswersAsKey, shouldRenderQuestionGroup: this.shouldRenderQuestionGroup }));
  }
  renderInternal() {
    return (index.h("form", { onSubmit: this.preventRefresh }, index.h("fieldset", { disabled: this.locked }, this._answers.map((answer) => this.renderAnswer(answer)))));
  }
  renderAnswer(answer) {
    var _a;
    if (!answer) {
      return null;
    }
    const shouldRenderGroup = this.shouldRenderQuestionGroup(this.questionGroupsWithAnswersAsKey, answer);
    return [
      !this.inQuestionGroup(answer) && (index.h("div", { class: index_esm_min.ix('bp-sdk-question-set bp-sdk-question-set__input', {
          'bp-sdk-coverage-width': ((_a = this.questionSet) === null || _a === void 0 ? void 0 : _a.order) === 1,
        }), "data-answerId": answer.id }, index.h("bp-sdk-dynamic-input-redux-container", { answer: answer }))),
      shouldRenderGroup && this.renderDynamicGroup(answer),
    ];
  }
  renderDynamicGroup(answer) {
    const mappedGroup = index_esm_min.p9(answer, this.questionGroupsWithAnswersAsKey);
    // This mapped group is rendered in a loop, so each item needs a unique key; otherwise Stencil may
    // try to reuse components and that can lead to corrupted state and odd behavior
    return mappedGroup && index.h("bp-sdk-question-group-container", { key: answer.id, questionGroup: mappedGroup });
  }
  static get watchers() { return {
    "questionSet": ["onQuestionSetChange"],
    "answers": ["onAnswersChange"],
    "deletedPool": ["onDeletedPoolChange"]
  }; }
};

const bpSdkQuestionSetHeaderCss = "";

let BpSdkQuestionSetHeader = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-set-header');
    customElements.whenDefined('bp-sdk-external-question-set-header').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-question-set-header", { applicationId: this.applicationId, code: this.code, isActive: this.isActive, isCompleted: this.isCompleted, name: this.name, setId: this.setId, setTitle: this.setTitle, tenantId: this.tenantId }));
  }
  renderInternal() {
    return index.h("div", { class: "bp-sdk-question-set-header__container" });
  }
};
BpSdkQuestionSetHeader.style = bpSdkQuestionSetHeaderCss;

const bpSdkVehicleQuestionSetCss = "";

let BpSdkVehicleQuestionSet = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.saveAnswer = index.createEvent(this, "saveAnswer", 7);
    /**
     * Maximum vehicles allowed
     */
    this.maxVehicles = 20;
    /**
     * A Map of nested question groups for rendering nested question groups/question pools
     */
    this.questionGroupsWithAnswersAsKey = new Map();
    this.vehicles = 1;
    this.useExternal = false;
    this.canDelete = (index) => {
      return index > 0 && index === this.vehicles - 1;
    };
    this.addVehicle = () => {
      var _a;
      const answer = index_esm_min.wL((_a = this.questionSet) === null || _a === void 0 ? void 0 : _a.answers);
      if (answer && this.vehicles < this.maxVehicles) {
        this.saveAnswer.emit({
          answer,
          new_value: (this.vehicles + 1).toString(),
        });
      }
    };
    this.deleteVehicle = () => {
      var _a;
      const answer = index_esm_min.wL((_a = this.questionSet) === null || _a === void 0 ? void 0 : _a.answers);
      if (answer && this.vehicles > 1) {
        this.saveAnswer.emit({
          answer,
          new_value: (this.vehicles - 1).toString(),
        });
      }
    };
    this.handleSaveClick = (e) => {
      if (this.useExternal) {
        return;
      }
      if (e.target['id'] === this.saveButtonId) {
        this.saveHandler(this.questionSet);
      }
    };
  }
  buildExtraGroupInformation() {
    return [...this.questionGroupsWithAnswersAsKey].reduce((acc, [key, mappedGroup]) => (Object.assign(Object.assign({}, acc), { [key]: {
        answers: index_esm_min.K9(mappedGroup),
      } })), {});
  }
  onQuestionSetChange(questionSet) {
    var _a, _b;
    const value = +((_b = (_a = index_esm_min.wL(questionSet === null || questionSet === void 0 ? void 0 : questionSet.answers)) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : 0);
    this.vehicles = value;
    this.saveButtonId = `bp-sdk-save-qs-${questionSet === null || questionSet === void 0 ? void 0 : questionSet.id}`;
  }
  onQuestionGroupsWithAnswersAsKeyChange(_) {
    this.extraGroupInformationMap = this.buildExtraGroupInformation();
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-question-set');
    customElements.whenDefined('bp-sdk-external-vehicle-question-set').then(() => {
      this.useExternal = true;
    });
    this.onQuestionSetChange(this.questionSet);
    this.onQuestionGroupsWithAnswersAsKeyChange(this.questionGroupsWithAnswersAsKey);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-vehicle-question-set", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, locked: this.locked, maxVehicles: this.maxVehicles, questionSet: this.questionSet, saveHandler: this.saveHandler, questionGroupsWithAnswersAsKey: this.questionGroupsWithAnswersAsKey }));
  }
  renderInternal() {
    return (index.h("fieldset", { disabled: this.locked, class: "bp-sdk-vehicle-question-set__container" }, index.h("bp-sdk-add-item-container", { canAddMore: this.vehicles && this.vehicles < this.maxVehicles, onAddItem: this.addVehicle, helpText: "Have additional Vehicles?", text: "Add vehicle" }, [...this.questionGroupsWithAnswersAsKey].map(([key, group], index$1) => {
      return (index.h("bp-sdk-vehicle-panel-container", { onDeleteItem: this.deleteVehicle, questionGroup: group, canDelete: this.canDelete(index$1), shouldShowTrailers: index$1 >= 1 || index_esm_min.f9(group), isVehicleTrailer: index_esm_min.f9(group), answers: this.extraGroupInformationMap[key].answers, code: group.parentQuestionAnswer.question.id }));
    })), index.h("bp-sdk-vehicle-question-set-button", { text: "Save Question Set", buttonId: this.saveButtonId, buttonDisabled: !this.areResourcesReady || !this.canSave, extraCssClasses: !this.areResourcesReady || !this.canSave ? 'loading' : 'not-loading', onClick: this.handleSaveClick })));
  }
  static get watchers() { return {
    "questionSet": ["onQuestionSetChange"],
    "questionGroupsWithAnswersAsKey": ["onQuestionGroupsWithAnswersAsKeyChange"]
  }; }
};
BpSdkVehicleQuestionSet.style = bpSdkVehicleQuestionSetCss;

exports.bp_sdk_application_load = BpSdkApplicationLoad;
exports.bp_sdk_driver_question_set_container = BpSdkDriverQuestionSetContainer;
exports.bp_sdk_pending_process_container = BpSdkPendingProcessContainer;
exports.bp_sdk_question_set = BpSdkQuestionSet;
exports.bp_sdk_question_set_header = BpSdkQuestionSetHeader;
exports.bp_sdk_vehicle_question_set = BpSdkVehicleQuestionSet;
