'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-2a6e6244.js');
const index_esm_min = require('./index.esm.min-83391a19.js');

const bpSdkDriverQuestionSetCss = "";

let BpSdkDriverQuestionSet = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.saveAnswer = index.createEvent(this, "saveAnswer", 7);
    /**
     * Maximum drivers allowed
     */
    this.maxDrivers = 20;
    /**
     * Mapped question groups
     */
    this.questionGroupsWithAnswersAsKey = new Map();
    this.drivers = 1;
    this.useExternal = false;
    this.addDriver = () => {
      var _a;
      const answer = index_esm_min.wL((_a = this.questionSet) === null || _a === void 0 ? void 0 : _a.answers);
      if (answer && this.drivers < this.maxDrivers) {
        this.saveAnswer.emit({
          answer,
          new_value: (this.drivers + 1).toString(),
        });
      }
    };
    this.deleteDriver = () => {
      var _a;
      const answer = index_esm_min.wL((_a = this.questionSet) === null || _a === void 0 ? void 0 : _a.answers);
      if (answer && this.drivers > 1) {
        this.saveAnswer.emit({
          answer,
          new_value: (this.drivers - 1).toString(),
        });
      }
    };
    this.handleSaveClick = (e) => {
      if (e.target['id'] === this.saveButtonId) {
        this.saveHandler(this.questionSet);
      }
    };
  }
  onQuestionSetChange(questionSet) {
    var _a, _b;
    const value = +((_b = (_a = index_esm_min.wL(questionSet === null || questionSet === void 0 ? void 0 : questionSet.answers)) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : 0);
    this.drivers = value;
    this.saveButtonId = `bp-sdk-save-qs-${questionSet === null || questionSet === void 0 ? void 0 : questionSet.id}`;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-question-set');
    customElements.whenDefined('bp-sdk-external-driver-question-set').then(() => {
      this.useExternal = true;
    });
    this.onQuestionSetChange(this.questionSet);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-driver-question-set", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, errors: this.errors, locked: this.locked, maxDrivers: this.maxDrivers, questionSet: this.questionSet, saveHandler: this.saveHandler, questionGroupsWithAnswersAsKey: this.questionGroupsWithAnswersAsKey }));
  }
  renderInternal() {
    return (index.h("div", { class: "bp-sdk-driver-question-set__container" }, index.h("bp-sdk-add-item-container", { canAddMore: this.drivers && this.drivers < this.maxDrivers, onAddItem: this.addDriver, helpText: "Have additional Drivers?", text: "Add driver" }, [...this.questionGroupsWithAnswersAsKey].map(([_, group]) => {
      return index.h("bp-sdk-driver-group", { group: group, errors: this.errors, canDelete: this.drivers > 1, onDeleteItem: this.deleteDriver });
    })), index.h("bp-sdk-driver-question-set-button", { text: "Save Question Set", buttonId: this.saveButtonId, buttonDisabled: !this.areResourcesReady || !this.canSave, onClick: this.handleSaveClick })));
  }
  static get watchers() { return {
    "questionSet": ["onQuestionSetChange"]
  }; }
};
BpSdkDriverQuestionSet.style = bpSdkDriverQuestionSetCss;

const bpSdkDriverQuestionSetButtonCss = "";

let BpSdkDriverQuestionSetButton = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Text to be displayed
     */
    this.text = '';
    /**
     * Id for button
     */
    this.buttonId = index_esm_min.fx(8);
    /**
     * Controls disabled state of button
     */
    this.buttonDisabled = false;
    this.useExternal = false;
    this.cssClasses = 'bp-sdk-driver-question-set-button__container';
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-question-set-button');
    customElements.whenDefined('bp-sdk-external-driver-question-set-button').then(() => {
      this.useExternal = true;
    });
    this.calculateButtonClasses(this.extraCssClasses);
  }
  calculateButtonClasses(extraClasses = '') {
    this.cssClasses = `bp-sdk-driver-question-set-button__container ${extraClasses}`;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return index.h("bp-sdk-external-driver-question-set-button", { class: this.extraCssClasses, text: this.text, buttonId: this.buttonId, buttonDisabled: this.buttonDisabled });
  }
  renderInternal() {
    return index.h("bp-sdk-button", { class: this.cssClasses, text: this.text, buttonId: this.buttonId, buttonDisabled: this.buttonDisabled });
  }
  static get watchers() { return {
    "extraCssClasses": ["calculateButtonClasses"]
  }; }
};
BpSdkDriverQuestionSetButton.style = bpSdkDriverQuestionSetButtonCss;

exports.bp_sdk_driver_question_set = BpSdkDriverQuestionSet;
exports.bp_sdk_driver_question_set_button = BpSdkDriverQuestionSetButton;
