import { Component, State, Prop, h, Watch, Element } from '@stencil/core';
import { store } from '@stencil/redux';
import { getMessages } from '@boldpenguin/sdk-redux';
import { canGetStore } from '../../utils/store';
export class BpSdkMessageContainer {
  constructor() {
    /**
     * Will use externally registered component
     */
    this.useExternal = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        messages: getMessages(state),
      };
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-message-container');
    customElements.whenDefined('bp-sdk-external-message-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
  }
  handleMessagesUpdate(messages) {
    this.lastMessage = messages[this.messages.length - 1];
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  componentWillUpdate() {
    this.handleSubscriptions();
  }
  render() {
    if (!canGetStore()) {
      return null;
    }
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-message-container", { messages: this.messages });
  }
  renderInternal() {
    return this.lastMessage && h("bp-sdk-message", { message: this.lastMessage });
  }
  static get is() { return "bp-sdk-message-container"; }
  static get properties() { return {
    "messages": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IMessage[]",
        "resolved": "IMessage[]",
        "references": {
          "IMessage": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Application form messages injected from redux"
      }
    }
  }; }
  static get states() { return {
    "useExternal": {},
    "lastMessage": {}
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "messages",
      "methodName": "handleMessagesUpdate"
    }]; }
}
