import { Component, h, Prop, State, Watch, Element } from '@stencil/core';
import { getAutocomplete } from '@boldpenguin/sdk-utility';
import { store } from '@stencil/redux';
import { isAutocompleteEnabled } from '@boldpenguin/sdk-redux';
import { canGetStore } from '../../utils/store';
export class BpSdkSelectInputContainer {
  constructor() {
    /**
     * Placeholder to display
     */
    this.placeholder = '';
    /**
     * Use alias for choices
     */
    this.useAlias = false;
    /**
     * Choice ids selected. Used for multiple selection.
     */
    this.choiceIds = [];
    /**
     * Whether to allow multi-select.
     */
    this.multiple = false;
    /**
     * Choices to display
     */
    this.choices = [];
    /**
     * Is Touched
     */
    this.touched = false;
    /**
     * Is Pristine
     */
    this.pristine = true;
    /**
     * Is answer in complete state
     */
    this.isCompleted = false;
    /**
     * When true, the field will be readonly. It will display only the label and value as plain text.
     */
    this.isReadOnly = false;
    this.useExternal = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        isAutocompleteEnabled: isAutocompleteEnabled(state),
      };
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-select-input-container');
    customElements.whenDefined('bp-sdk-external-select-input-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.updateAutocomplete({
      referenceType: this.referenceType,
      code: this.code,
      fieldType: this.fieldType,
      isAutocompleteEnabled: this.isAutocompleteEnabled,
    });
  }
  onReferenceTypeChange(referenceType) {
    this.updateAutocomplete({
      referenceType,
      code: this.code,
      fieldType: this.fieldType,
      isAutocompleteEnabled: this.isAutocompleteEnabled,
    });
  }
  onCodeChange(code) {
    this.updateAutocomplete({
      referenceType: this.referenceType,
      code,
      fieldType: this.fieldType,
      isAutocompleteEnabled: this.isAutocompleteEnabled,
    });
  }
  onFieldTypeChange(fieldType) {
    this.updateAutocomplete({
      referenceType: this.referenceType,
      code: this.code,
      fieldType,
      isAutocompleteEnabled: this.isAutocompleteEnabled,
    });
  }
  onIsAutocompleteEnabledChange(isAutocompleteEnabled) {
    this.updateAutocomplete({
      referenceType: this.referenceType,
      code: this.code,
      fieldType: this.fieldType,
      isAutocompleteEnabled,
    });
  }
  updateAutocomplete({ code, fieldType, referenceType, isAutocompleteEnabled, }) {
    this.autoComplete = isAutocompleteEnabled ? getAutocomplete({ referenceType, code, fieldType }) : undefined;
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-select-input-container", { answerId: this.answerId, choiceId: this.choiceId, choiceIds: this.choiceIds, choices: this.choices, code: this.code, errors: this.errors, errorText: this.errorText, fieldType: this.fieldType, helpText: this.helpText, answeredBySource: this.answeredBySource, isCompleted: this.isCompleted, isReadOnly: this.isReadOnly, label: this.label, labelId: this.labelId, labelledBy: this.labelledBy, multiple: this.multiple, placeholder: this.placeholder, pristine: this.pristine, questionId: this.questionId, referenceType: this.referenceType, required: this.required, touched: this.touched, useAlias: this.useAlias, value: this.value }));
  }
  renderInternal() {
    return (h("bp-sdk-select-input", { answerId: this.answerId, autoComplete: this.autoComplete, choiceId: this.choiceId, choiceIds: this.choiceIds, choices: this.choices, code: this.code, errors: this.errors, errorText: this.errorText, helpText: this.helpText, answeredBySource: this.answeredBySource, fieldType: this.fieldType, isCompleted: this.isCompleted, isReadOnly: this.isReadOnly, label: this.label, labelId: this.labelId, labelledBy: this.labelledBy, multiple: this.multiple, placeholder: this.placeholder, pristine: this.pristine, questionId: this.questionId, required: this.required, touched: this.touched, useAlias: this.useAlias }));
  }
  static get is() { return "bp-sdk-select-input-container"; }
  static get originalStyleUrls() { return {
    "$": ["./bp-sdk-select-input-container.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-select-input-container.css"]
  }; }
  static get properties() { return {
    "answerId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Answer id"
      },
      "attribute": "answer-id",
      "reflect": false
    },
    "placeholder": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Placeholder to display"
      },
      "attribute": "placeholder",
      "reflect": false,
      "defaultValue": "''"
    },
    "useAlias": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Use alias for choices"
      },
      "attribute": "use-alias",
      "reflect": false,
      "defaultValue": "false"
    },
    "code": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question code"
      },
      "attribute": "code",
      "reflect": false
    },
    "choiceId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Choice id selected. Used for single selection."
      },
      "attribute": "choice_id",
      "reflect": false
    },
    "choiceIds": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "string[]",
        "resolved": "string[]",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Choice ids selected. Used for multiple selection."
      },
      "defaultValue": "[]"
    },
    "multiple": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether to allow multi-select."
      },
      "attribute": "multiple",
      "reflect": false,
      "defaultValue": "false"
    },
    "choices": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IChoice[]",
        "resolved": "IChoice[]",
        "references": {
          "IChoice": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Choices to display"
      },
      "defaultValue": "[]"
    },
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Current value"
      },
      "attribute": "value",
      "reflect": false
    },
    "labelId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Aria label id's that describes input for screen readers"
      },
      "attribute": "label-id",
      "reflect": false
    },
    "errors": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "string[]",
        "resolved": "string[]",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Error messages"
      }
    },
    "errorText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Error text"
      },
      "attribute": "error_text",
      "reflect": false
    },
    "touched": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is Touched"
      },
      "attribute": "touched",
      "reflect": false,
      "defaultValue": "false"
    },
    "pristine": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is Pristine"
      },
      "attribute": "pristine",
      "reflect": false,
      "defaultValue": "true"
    },
    "isCompleted": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is answer in complete state"
      },
      "attribute": "is_completed",
      "reflect": false,
      "defaultValue": "false"
    },
    "isReadOnly": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "When true, the field will be readonly. It will display only the label and value as plain text."
      },
      "attribute": "is-read-only",
      "reflect": false,
      "defaultValue": "false"
    },
    "questionId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question Id"
      },
      "attribute": "question_id",
      "reflect": false
    },
    "fieldType": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Field type"
      },
      "attribute": "field_type",
      "reflect": false
    },
    "required": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is required"
      },
      "attribute": "required",
      "reflect": false
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label to use"
      },
      "attribute": "label",
      "reflect": false
    },
    "labelledBy": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Labels that describe group"
      },
      "attribute": "labelled-by",
      "reflect": false
    },
    "referenceType": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Reference type"
      },
      "attribute": "reference-type",
      "reflect": false
    },
    "isAutocompleteEnabled": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is autocomplete enabled"
      },
      "attribute": "is-autocomplete-enabled",
      "reflect": false
    },
    "helpText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Help text"
      },
      "attribute": "help-text",
      "reflect": false
    },
    "answeredBySource": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | undefined",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifically how the question was answered (ie. \"ACORD 126\")"
      },
      "attribute": "answered-by-source",
      "reflect": false
    }
  }; }
  static get states() { return {
    "autoComplete": {},
    "useExternal": {}
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "referenceType",
      "methodName": "onReferenceTypeChange"
    }, {
      "propName": "code",
      "methodName": "onCodeChange"
    }, {
      "propName": "fieldType",
      "methodName": "onFieldTypeChange"
    }, {
      "propName": "isAutocompleteEnabled",
      "methodName": "onIsAutocompleteEnabledChange"
    }]; }
}
