import { r as registerInstance, h, c as createEvent, g as getElement } from './index-b4e0290f.js';
import { $ as $L, e as fx, i as ix, s as s9, F as Fe, u as u4 } from './index.esm.min-7f929673.js';
import { removeQuestionPool, getFormId, getPartnerEngineConfig, getQuestionSets, getVehicleOptionsMakes, getVehicleOptionsSelection, getVehicleOptionsModels, loadVin, getVehicleOptionsConfigurations, getVehicleOptionsVin, getVinSelectionState, loadYears, getVehicleOptionsYears } from '@boldpenguin/sdk-redux';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';
import { R, C as Ce, i } from './index.esm.min-5e144817.js';
import { V as VehicleVinService } from './vehicle-vin.service-b4141650.js';

const bpSdkAccordionCss = "";

let BpSdkAccordion = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-accordion');
    customElements.whenDefined('bp-sdk-external-accordion').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-accordion", { questionGroup: this.questionGroup });
  }
  renderInternal() {
    var _a, _b, _c;
    return (h("div", { class: "bp-sdk-accordion__container" }, h("bp-sdk-question-group-label", { labelId: (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.groupId, label: (_b = this.questionGroup) === null || _b === void 0 ? void 0 : _b.parentQuestionAnswer.question.text }), (_c = this.questionGroup) === null || _c === void 0 ? void 0 :
      _c.answers.map((answer) => (h("bp-sdk-dynamic-input-redux-container", { answer: answer, id: `bp-sdk-question-group__${answer.question.id}` })))));
  }
};
BpSdkAccordion.style = bpSdkAccordionCss;

const bpSdkAccumulationQuestionGroupContainerCss = "";

let BpSdkAccumulationQuestionGroupContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-accumulation-question-group-container');
    customElements.whenDefined('bp-sdk-external-accumulation-question-group-container').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-accumulation-question-group-container", { answers: this.answers, label: this.label, labelledBy: this.labelledBy });
  }
  renderInternal() {
    return h("bp-sdk-accumulation-question-group", { answers: this.answers, label: this.label, labelledBy: this.labelledBy });
  }
};
BpSdkAccumulationQuestionGroupContainer.style = bpSdkAccumulationQuestionGroupContainerCss;

const bpSdkAddressGroupCss = "";

let BpSdkAddressGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.saveAnswer = createEvent(this, "saveAnswer", 7);
    this.addressMissingComponents = createEvent(this, "addressMissingComponents", 7);
    /**
     * group of answers
     */
    this.answers = [];
    this.answerMap = {};
    this.useExternal = false;
    this.updateInputs = (address) => () => {
      this.updateStreet(address);
      this.updateCity(address);
      this.updateState(address);
      this.updateZip(address);
    };
    /**
     * Emits addressMissingComponents event if any required
     * address components are missing
     *
     * @param addressComponents The array of address components from Google
     */
    this.handleMissingAddressComponents = (addressComponents) => {
      const missingComponents = this.getMissingAddressComponents(addressComponents);
      if (missingComponents.length) {
        this.addressMissingComponents.emit({
          missing_components: missingComponents,
        });
      }
    };
    /**
     * Finds the address components that are missing in the Google data
     *
     * @param addressComponents The array of address components from Google
     * @returns Returns an array of missing address component types
     */
    this.getMissingAddressComponents = (addressComponents) => {
      const requiredAddressComponentTypes = ['street_number', 'route', 'locality', 'administrative_area_level_1', 'postal_code'];
      return requiredAddressComponentTypes.filter((requiredAddressComponentType) => {
        return !addressComponents.some((addressComponent) => addressComponent.types[0] === requiredAddressComponentType);
      });
    };
  }
  onAnswersChange(newAnswers) {
    const map = {};
    newAnswers.forEach((answer) => {
      var _a;
      if ((_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.reference_type) {
        map[answer.question.reference_type] = answer;
      }
    });
    this.answerMap = map;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-address-group');
    customElements.whenDefined('bp-sdk-external-address-group').then(() => {
      this.useExternal = true;
    });
    this.onAnswersChange(this.answers);
  }
  emitSaveAnswer(answer, newValue) {
    this.saveAnswer.emit({
      answer,
      new_value: newValue,
    });
  }
  onPlacesUpdate({ detail }) {
    if (this.useExternal) {
      return;
    }
    const address = {};
    if (detail.address_components) {
      detail.address_components.forEach((addressComponent) => {
        address[addressComponent.types[0]] = {
          short: addressComponent.short_name,
          long: addressComponent.long_name,
        };
      });
      setTimeout(this.updateInputs(address), 0);
      this.handleMissingAddressComponents(detail.address_components);
    }
    this.updateJson(detail);
  }
  updateStreet(address) {
    if (address['street_number'] && address['route']) {
      const street_answer = this.answerMap['street_1'];
      if (street_answer) {
        this.emitSaveAnswer(Object.assign({}, street_answer), `${address['street_number'].long} ${address['route'].long}`);
      }
    }
  }
  updateCity(address) {
    if (address['locality']) {
      const city_answer = this.answerMap['city'];
      if (city_answer) {
        this.emitSaveAnswer(Object.assign({}, city_answer), address['locality'].long);
      }
    }
  }
  updateState(address) {
    if (address['administrative_area_level_1']) {
      const state_answer = this.answerMap['state'];
      if (state_answer) {
        const state = address['administrative_area_level_1'].short;
        const state_choice = state_answer.question.choices.find((choice) => choice.alias === state);
        if (state_choice) {
          this.emitSaveAnswer(Object.assign({}, state_answer), [state_choice.id]);
        }
      }
    }
  }
  updateZip(address) {
    if (address['postal_code']) {
      const zip_answer = this.answerMap['zipcode'];
      if (zip_answer) {
        this.emitSaveAnswer(Object.assign({}, zip_answer), address['postal_code'].long);
      }
    }
  }
  updateJson(place) {
    const json_answer = this.answerMap['address_json'];
    if (json_answer) {
      this.emitSaveAnswer(Object.assign({}, json_answer), JSON.stringify(place));
    }
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-address-group", { answers: this.answers, label: this.label, labelledBy: this.labelledBy });
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-address-group__container" }, h("div", { class: "bp-sdk-address-group__streets" }, h("div", { class: "bp-sdk-row" }, this.answerMap['street_1'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group-street-primary", labelledBy: this.labelledBy, shouldHideLabel: $L(this.label, this.answerMap['street_1']), answer: this.answerMap['street_1'] })), this.answerMap['street_2'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group-street-secondary", labelledBy: this.labelledBy, shouldHideLabel: $L(this.label, this.answerMap['street_2']), answer: this.answerMap['street_2'] })))), h("div", { class: "bp-sdk-address-group__locality" }, h("div", { class: "bp-sdk-row" }, this.answerMap['city'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group__city", labelledBy: this.labelledBy, shouldHideLabel: $L(this.label, this.answerMap['city']), answer: this.answerMap['city'] })), this.answerMap['state'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group__state", labelledBy: this.labelledBy, shouldHideLabel: $L(this.label, this.answerMap['state']), answer: this.answerMap['state'], useSelectAlias: true })), this.answerMap['zipcode'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group__zipcode", labelledBy: this.labelledBy, shouldHideLabel: $L(this.label, this.answerMap['zipcode']), answer: this.answerMap['zipcode'] })))), this.answerMap['address_json'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group-address__json", labelledBy: this.labelledBy, shouldHideLabel: $L(this.label, this.answerMap['address_json']), answer: this.answerMap['address_json'], hidden: true }))));
  }
  static get watchers() { return {
    "answers": ["onAnswersChange"]
  }; }
};
BpSdkAddressGroup.style = bpSdkAddressGroupCss;

const bpSdkDriverQuestionPoolContainerCss = "";

let BpSdkDriverQuestionPoolContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.deletePool = createEvent(this, "deletePool", 7);
    this.questionSets = [];
    this.useExternal = false;
    this.isDeleting = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { removeQuestionPool });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        applicationId: getFormId(state),
        config: getPartnerEngineConfig(state),
        questionSets: getQuestionSets(state),
      };
    };
    this.handleDeleteItem = () => {
      this.isDeleting = true;
      this.removeQuestionPool({
        answer_pool_id: this.questionPoolId,
        application_id: this.applicationId,
        config: this.config,
        callback: () => {
          this.deletePool.emit(undefined);
        },
      });
      this.deletePool.emit(this.questionPoolId);
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onQuestionGroupChange(questionGroup) {
    this.questionPoolId = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.poolId;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-question-pool-container');
    customElements.whenDefined('bp-sdk-external-driver-question-pool-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-driver-question-pool-container", { applicationId: this.applicationId, config: this.config, questionGroup: this.questionGroup, questionSets: this.questionSets }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-driver-question-pool-container__container" }, !this.isDeleting && !!this.questionPoolId && (h("bp-sdk-driver-group", { group: this.questionGroup, canDelete: true, onDeleteItem: this.handleDeleteItem }))));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkDriverQuestionPoolContainer.style = bpSdkDriverQuestionPoolContainerCss;

const bpSdkQuestionGroupContainerCss = "";

let BpSdkQuestionGroupContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.classes = 'bp-sdk-question-group-content';
    this.labelId = fx(8);
    this.useExternal = false;
  }
  onQuestionGroupChange(questionGroup) {
    if (this.type !== (questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.group_type)) {
      this.type = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.group_type;
    }
  }
  onTypeChange(type) {
    this.updateClasses(type);
  }
  resetState() {
    var _a;
    this.type = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.group_type;
  }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    var _a;
    this.useExternal = !!customElements.get('bp-sdk-external-question-group-container');
    customElements.whenDefined('bp-sdk-external-question-group-container').then(() => {
      this.useExternal = true;
    });
    this.type = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.group_type;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-question-group-container", { questionGroup: this.questionGroup });
  }
  renderInternal() {
    var _a, _b, _c;
    return (h("bp-sdk-question-group", { answers: (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers, classes: this.classes, label: (_b = this.questionGroup) === null || _b === void 0 ? void 0 : _b.label, labelId: this.labelId, questionGroup: this.questionGroup, type: (_c = this.questionGroup) === null || _c === void 0 ? void 0 : _c.group_type }));
  }
  updateClasses(type) {
    if (!type) {
      this.classes = 'bp-sdk-question-group-content';
      return;
    }
    this.classes = ix('bp-sdk-question-group-content', {
      'bp-sdk-row': type === 'split_horizontal',
      'bp-sdk-column': type !== 'split_horizontal',
      'bp-sdk-space-between': type === 'split_horizontal',
    });
  }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"],
    "type": ["onTypeChange"]
  }; }
};
BpSdkQuestionGroupContainer.style = bpSdkQuestionGroupContainerCss;

const bpSdkStepperGroupContainerCss = "";

let BpSdkStepperGroupContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.currentActiveStepper = 0;
    this.previousStep = null;
    this.nextStep = null;
    this.buttonDisable = false;
    this.useExternal = false;
    this.handleStepperClick = (answerId) => {
      const index = this.questionGroup.answers.findIndex((answer) => answer.id === answerId);
      this.currentActiveStepper = index >= 0 ? index : 0;
    };
    this.handleButtonClick = (answerId, direction) => {
      if (direction === 'forward') {
        this.currentActiveStepper += 1;
      }
      else {
        this.currentActiveStepper -= 1;
      }
    };
  }
  onCurrentActiveStepChange(index) {
    var _a, _b, _c, _d, _e, _f;
    this.currentActiveStepperId = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers[index]) === null || _b === void 0 ? void 0 : _b.id;
    this.previousStep = (_d = (_c = this.questionGroup) === null || _c === void 0 ? void 0 : _c.answers[index - 1]) !== null && _d !== void 0 ? _d : null;
    this.nextStep = (_f = (_e = this.questionGroup) === null || _e === void 0 ? void 0 : _e.answers[index + 1]) !== null && _f !== void 0 ? _f : null;
    this.updateButtonDisabled();
  }
  onQuestionGroupChange(questionGroup) {
    var _a, _b;
    if (!!questionGroup) {
      this.currentActiveStepperId = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers[this.currentActiveStepper]) === null || _b === void 0 ? void 0 : _b.id;
      this.updateButtonDisabled();
    }
  }
  resetState() {
    var _a, _b;
    this.currentActiveStepper = 0;
    this.previousStep = null;
    this.nextStep = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers[this.currentActiveStepper + 1]) !== null && _b !== void 0 ? _b : null;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-stepper-group-container');
    customElements.whenDefined('bp-sdk-external-stepper-group-container').then(() => {
      this.useExternal = true;
    });
    this.onCurrentActiveStepChange(this.currentActiveStepper);
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderCurrentQuestionGroup(currentActiveStepperId) {
    var _a;
    const currentGroup = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.nestedGroupsWithAnswers.get(currentActiveStepperId);
    return (h("div", { class: "bp-sdk-stepper-group-container__current-group" }, h("bp-sdk-stepper-group", { questionGroup: currentGroup })));
  }
  renderExternal() {
    return h("bp-sdk-external-stepper-group-container", { questionGroup: this.questionGroup });
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-stepper-group-container__container" }, this.renderCurrentQuestionGroup(this.currentActiveStepperId), h("bp-sdk-stepper-group-button", { answer: this.previousStep, direction: "backward", buttonDisabled: false, handleStepperButtonClick: this.handleButtonClick }), h("bp-sdk-stepper-group-button", { answer: this.nextStep, direction: "forward", buttonDisabled: this.buttonDisable, handleStepperButtonClick: this.handleButtonClick })));
  }
  updateButtonDisabled() {
    var _a;
    if (!!this.currentActiveStepperId) {
      const group = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.nestedGroupsWithAnswers.get(this.currentActiveStepperId);
      const aggregateAnswers = [
        ...group.answers,
        ...group.answers.filter((answer) => {
          if (group.nestedGroupsWithAnswers.has(answer.id)) {
            return group.nestedGroupsWithAnswers.get(answer.id).answers;
          }
        }),
      ];
      this.buttonDisable = !aggregateAnswers.every((answer) => { var _a; return !!answer.choice_id || ((_a = answer.choice_ids) === null || _a === void 0 ? void 0 : _a.length) > 0 || !!answer.value || !answer.required || answer.display_type === 'private'; });
    }
  }
  static get watchers() { return {
    "currentActiveStepper": ["onCurrentActiveStepChange"],
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkStepperGroupContainer.style = bpSdkStepperGroupContainerCss;

const bpSdkVehicleDeleteButtonCss = ".bp-sdk-vehicle-delete-button{appearance:none;font-weight:bold;cursor:pointer;height:100%;width:3rem}";

let BpSdkVehicleDeleteButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-delete-button');
    customElements.whenDefined('bp-sdk-external-vehicle-delete-button').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-vehicle-delete-button", null);
  }
  renderInternal() {
    return (h("button", { type: "button", class: "bp-sdk-vehicle-delete-button" }, h("bp-sdk-model-container", { name: "trashcan" }, "Delete")));
  }
};
BpSdkVehicleDeleteButton.style = bpSdkVehicleDeleteButtonCss;

const bpSdkVehicleEditButtonCss = ".bp-sdk-vehicle-edit-button{appearance:none;font-weight:bold;cursor:pointer;height:100%;width:3rem}";

let BpSdkVehicleEditButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-edit-button');
    customElements.whenDefined('bp-sdk-external-vehicle-edit-button').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-vehicle-edit-button", null);
  }
  renderInternal() {
    return (h("button", { type: "button", class: "bp-sdk-vehicle-edit-button" }, "Edit"));
  }
};
BpSdkVehicleEditButton.style = bpSdkVehicleEditButtonCss;

const bpSdkVehicleInterfaceCss = "";

const vehicleQuestionCodes = {
  year: 'mqs_vehicle_year',
  make: 'mqs_vehicle_make',
  model: 'mqs_vehicle_model',
  configuration: 'mqs_vehicle_submodel',
};
let BpSdkVehicleInterface = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.saveVehicle = createEvent(this, "saveVehicle", 7);
    /**
     * Can Save
     */
    this.canSave = true;
    /**
     * Is vehicle a trailer
     */
    this.isVehicleTrailer = false;
    this.useExternal = false;
    this.answerIdMap = {
      year: '',
      make: '',
      model: '',
      configuration: '',
    };
  }
  onQuestionGroupChange() {
    this.answerIdMap = this.buildAnswerIdMap();
  }
  resetState() {
    this.answerIdMap = {
      year: '',
      make: '',
      model: '',
      configuration: '',
    };
  }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-interface');
    customElements.whenDefined('bp-sdk-external-vehicle-interface').then(() => {
      this.useExternal = true;
    });
    this.answerIdMap = this.buildAnswerIdMap();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-vehicle-interface", { isVehicleTrailer: this.isVehicleTrailer, questionGroup: this.questionGroup });
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-vehicle-interface__container" }, h("bp-sdk-vehicle-years-container", { isVehicleTrailer: this.isVehicleTrailer, questionGroupId: s9(this.questionGroup), code: vehicleQuestionCodes.year, answerId: this.answerIdMap.year }), h("bp-sdk-vehicle-makes-container", { isVehicleTrailer: this.isVehicleTrailer, questionGroupId: s9(this.questionGroup), code: vehicleQuestionCodes.make, answerId: this.answerIdMap.make }), h("bp-sdk-vehicle-models-container", { isVehicleTrailer: this.isVehicleTrailer, questionGroupId: s9(this.questionGroup), code: vehicleQuestionCodes.model, answerId: this.answerIdMap.model }), h("bp-sdk-vehicle-configurations-container", { questionGroupId: s9(this.questionGroup), code: vehicleQuestionCodes.configuration, answerId: this.answerIdMap.configuration })));
  }
  buildAnswerIdMap() {
    var _a, _b, _c, _d, _e, _f;
    const answers = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers) !== null && _b !== void 0 ? _b : [];
    const yearAnswer = answers.find((answer) => answer.question.code === vehicleQuestionCodes.year);
    const makeAnswer = answers.find((answer) => answer.question.code === vehicleQuestionCodes.make);
    const modelAnswer = answers.find((answer) => answer.question.code === vehicleQuestionCodes.model);
    const configurationAnswer = answers.find((answer) => answer.question.code === vehicleQuestionCodes.configuration);
    return {
      year: (_c = yearAnswer === null || yearAnswer === void 0 ? void 0 : yearAnswer.id) !== null && _c !== void 0 ? _c : '',
      make: (_d = makeAnswer === null || makeAnswer === void 0 ? void 0 : makeAnswer.id) !== null && _d !== void 0 ? _d : '',
      model: (_e = modelAnswer === null || modelAnswer === void 0 ? void 0 : modelAnswer.id) !== null && _e !== void 0 ? _e : '',
      configuration: (_f = configurationAnswer === null || configurationAnswer === void 0 ? void 0 : configurationAnswer.id) !== null && _f !== void 0 ? _f : '',
    };
  }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkVehicleInterface.style = bpSdkVehicleInterfaceCss;

const bpSdkVehicleMakesCss = "";

let BpSdkVehicleMakes = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Is pristine
     */
    this.pristine = true;
    /**
     * Is touched
     */
    this.touched = false;
    /**
     * Error messages
     */
    this.errors = [];
    /**
     * Makes choices
     */
    this.makes = [];
    /**
     * Is vehicle a trailer
     */
    this.isVehicleTrailer = false;
    this.useExternal = false;
    this.fieldType = 'dropdown';
    this.inputComponentType = 'dropdown';
  }
  onIsVehicleTrailerChange(isTrailer) {
    this.fieldType = isTrailer ? 'vehicle' : 'dropdown';
    this.inputComponentType = isTrailer ? 'vehicle' : 'dropdown';
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-makes');
    customElements.whenDefined('bp-sdk-external-vehicle-makes').then(() => {
      this.useExternal = true;
    });
    this.onIsVehicleTrailerChange(this.isVehicleTrailer);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-makes", { answerId: this.answerId, code: this.code, errors: this.errors, isVehicleTrailer: this.isVehicleTrailer, label: this.label, makes: this.makes, pristine: this.pristine, selectedMakeId: this.selectedMakeId, touched: this.touched }));
  }
  renderInternal() {
    return (h("bp-sdk-dynamic-input-wrapper", { answerId: this.answerId, choiceId: this.selectedMakeId, choices: this.makes, code: this.code, errors: this.errors, fieldType: this.fieldType, inputComponentType: this.inputComponentType, isAutocomplete: this.isVehicleTrailer, isLabelledField: true, isRequired: true, label: this.label, pristine: this.pristine, referenceType: "makes", touched: this.touched }));
  }
  static get watchers() { return {
    "isVehicleTrailer": ["onIsVehicleTrailerChange"]
  }; }
};
BpSdkVehicleMakes.style = bpSdkVehicleMakesCss;

const bpSdkVehicleMakesContainerCss = "";

let BpSdkVehicleMakesContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.ymmcUpdate = createEvent(this, "ymmcUpdate", 7);
    /**
     * Vehicle options injected by redux
     */
    this.makeOptions = {};
    /**
     * Current vehicle selection injected by redux
     */
    this.selectedVehicle = {};
    /**
     * Is vehicle a trailer
     */
    this.isVehicleTrailer = false;
    this.choices = [];
    this.filteredChoices = [];
    this.useExternal = false;
    this.touched = false;
    this.pristine = true;
    this.errors = [];
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        makeOptions: getVehicleOptionsMakes(state, this.questionGroupId),
        selectedVehicle: getVehicleOptionsSelection(state, this.questionGroupId),
      };
    };
    this.onFocusOut = () => {
      this.touched = true;
      this.updateErrors(this.pristine, true, this.value);
    };
  }
  resetState() {
    this.touched = false;
    this.pristine = true;
    this.value = undefined;
    this.errors = [];
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-makes-container');
    customElements.whenDefined('bp-sdk-external-vehicle-makes-container').then(() => {
      this.useExternal = true;
    });
    this.onQuestionGroupIdChange();
  }
  onQuestionGroupIdChange() {
    this.handleSubscriptions();
  }
  onMakesChange(makes) {
    if (makes) {
      this.choices = this.convertMakesToChoices(makes);
      this.updateValue(makes, this.selectedVehicle);
    }
    else {
      this.updateValue(undefined, undefined);
    }
  }
  onVehicleSelectionChange(selection) {
    if (!(selection === null || selection === void 0 ? void 0 : selection.makeId)) {
      this.touched = false;
      this.pristine = true;
    }
    this.updateValue(this.makeOptions, selection);
  }
  updateValue(makes, selection) {
    this.value = !!(makes && (selection === null || selection === void 0 ? void 0 : selection.makeId)) ? makes[selection.makeId] : undefined;
  }
  onUseExternalChange(useExternal) {
    if (!useExternal) {
      this.unloadFocusEvents();
    }
  }
  loadFocusEvents() {
    if (!this.useExternal) {
      this.el.addEventListener('focusout', this.onFocusOut);
    }
  }
  unloadFocusEvents() {
    this.el.removeEventListener('focusout', this.onFocusOut);
  }
  componentDidLoad() {
    this.loadFocusEvents();
  }
  disconnectedCallback() {
    this.unloadFocusEvents();
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onFilterUpdate({ detail }) {
    var _a;
    this.filter = (_a = detail === null || detail === void 0 ? void 0 : detail.value) !== null && _a !== void 0 ? _a : '';
  }
  onFilterChange(filter) {
    this.updateChoices(this.choices, filter);
  }
  onChoicesChange(choices) {
    this.updateChoices(choices, this.filter);
  }
  updateChoices(choices, filter = '') {
    const regex = new RegExp(`.*${filter}.*`, 'gi');
    this.filteredChoices = choices.filter((choice) => !!choice.value.match(regex));
  }
  onValueUpdate(evt) {
    var _a, _b;
    if (this.useExternal) {
      return;
    }
    this.pristine = false;
    const value = ((_a = evt.detail) !== null && _a !== void 0 ? _a : [])[0];
    if (Fe(value, this.value) && (this.errors.length === 0 || !!value)) {
      this.value = value;
      const displayValue = (_b = this.makeOptions[value]) !== null && _b !== void 0 ? _b : value;
      this.ymmcUpdate.emit({ type: R.Make, value, displayValue });
    }
  }
  onValueChange(value) {
    this.updateErrors(false, this.touched, value);
  }
  updateErrors(pristine, touched, value) {
    this.errors = u4(pristine, touched, value) ? ['required'] : [];
  }
  onMakeDirty() {
    this.touched = true;
    this.pristine = false;
    this.updateErrors(false, this.touched, this.value);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-makes-container", { answerId: this.answerId, code: this.code, isVehicleTrailer: this.isVehicleTrailer, makeOptions: this.makeOptions, questionGroupId: this.questionGroupId, selectedVehicle: this.selectedVehicle }));
  }
  convertMakesToChoices(makes) {
    const choices = [];
    for (const makeId of Object.keys(makes)) {
      choices.push({ id: makeId, value: makes[makeId] });
    }
    choices.sort((a, b) => a.value.localeCompare(b.value));
    return choices;
  }
  renderInternal() {
    var _a;
    return (this.choices.length > 0 && (h("bp-sdk-vehicle-makes", { answerId: this.answerId, code: this.code, errors: this.errors, isVehicleTrailer: this.isVehicleTrailer, label: "Enter vehicle make", makes: this.filteredChoices, pristine: this.pristine, selectedMakeId: (_a = this.selectedVehicle) === null || _a === void 0 ? void 0 : _a.makeId, touched: this.touched })));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroupId": ["onQuestionGroupIdChange"],
    "makeOptions": ["onMakesChange"],
    "selectedVehicle": ["onVehicleSelectionChange"],
    "useExternal": ["onUseExternalChange"],
    "filter": ["onFilterChange"],
    "choices": ["onChoicesChange"],
    "value": ["onValueChange"]
  }; }
};
BpSdkVehicleMakesContainer.style = bpSdkVehicleMakesContainerCss;

const bpSdkVehicleModelsCss = "";

let BpSdkVehicleModels = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Is pristine
     */
    this.pristine = true;
    /**
     * Is touched
     */
    this.touched = false;
    /**
     * Error messages
     */
    this.errors = [];
    /**
     * Models choices
     */
    this.models = [];
    /**
     * Is vehicle a trailer
     */
    this.isVehicleTrailer = false;
    this.useExternal = false;
    this.fieldType = 'dropdown';
    this.inputComponentType = 'dropdown';
  }
  onIsVehicleTrailerChange(isTrailer) {
    this.fieldType = isTrailer ? 'vehicle' : 'dropdown';
    this.inputComponentType = isTrailer ? 'vehicle' : 'dropdown';
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-models');
    customElements.whenDefined('bp-sdk-external-vehicle-models').then(() => {
      this.useExternal = true;
    });
    this.onIsVehicleTrailerChange(this.isVehicleTrailer);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-models", { answerId: this.answerId, code: this.code, errors: this.errors, isVehicleTrailer: this.isVehicleTrailer, label: this.label, models: this.models, pristine: this.pristine, selectedModelId: this.selectedModelId, touched: this.touched }));
  }
  renderInternal() {
    return (h("bp-sdk-dynamic-input-wrapper", { answerId: this.answerId, choiceId: this.selectedModelId, choices: this.models, code: this.code, errors: this.errors, fieldType: this.fieldType, inputComponentType: this.inputComponentType, isAutocomplete: this.isVehicleTrailer, isLabelledField: true, isRequired: true, label: this.label, pristine: this.pristine, referenceType: "models", touched: this.touched }));
  }
  static get watchers() { return {
    "isVehicleTrailer": ["onIsVehicleTrailerChange"]
  }; }
};
BpSdkVehicleModels.style = bpSdkVehicleModelsCss;

const bpSdkVehicleModelsContainerCss = "";

let BpSdkVehicleModelsContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.ymmcUpdate = createEvent(this, "ymmcUpdate", 7);
    /**
     * Vehicle options injected by redux
     */
    this.modelOptions = {};
    /**
     * Current vehicle selection injected by redux
     */
    this.selectedVehicle = {};
    /**
     * Is vehicle a trailer
     */
    this.isVehicleTrailer = false;
    this.choices = [];
    this.useExternal = false;
    this.filteredChoices = [];
    this.touched = false;
    this.pristine = true;
    this.errors = [];
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        modelOptions: getVehicleOptionsModels(state, this.questionGroupId),
        selectedVehicle: getVehicleOptionsSelection(state, this.questionGroupId),
      };
    };
    this.onFocusOut = () => {
      this.touched = true;
      this.updateErrors(this.pristine, true, this.value);
    };
  }
  resetState() {
    this.touched = false;
    this.pristine = true;
    this.value = undefined;
    this.errors = [];
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-models-container');
    customElements.whenDefined('bp-sdk-external-vehicle-models-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupIdChange();
  }
  onQuestionGroupIdChange() {
    this.handleSubscriptions();
  }
  onModelsChange(models) {
    this.choices = this.convertModelsToChoices(models);
    this.updateValue(models, this.selectedVehicle);
  }
  onSelectionChange(selection) {
    if (!(selection === null || selection === void 0 ? void 0 : selection.modelId)) {
      this.touched = false;
      this.pristine = true;
    }
    this.updateValue(this.modelOptions, selection);
  }
  onFilterUpdate({ detail }) {
    var _a;
    this.filter = (_a = detail === null || detail === void 0 ? void 0 : detail.value) !== null && _a !== void 0 ? _a : '';
  }
  onFilterChange(filter) {
    this.updateChoices(this.choices, filter);
  }
  onChoicesChange(choices) {
    this.updateChoices(choices, this.filter);
  }
  updateChoices(choices, filter = '') {
    const regex = new RegExp(`.*${filter}.*`, 'gi');
    this.filteredChoices = choices.filter((choice) => !!choice.value.match(regex));
  }
  updateValue(models, selection) {
    const newValue = !!(models && (selection === null || selection === void 0 ? void 0 : selection.modelId)) ? models[selection.modelId] : undefined;
    this.value = newValue;
  }
  componentDidLoad() {
    this.loadFocusEvents();
  }
  disconnectedCallback() {
    this.unloadFocusEvents();
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onUseExternalChange(useExternal) {
    if (!useExternal) {
      this.unloadFocusEvents();
    }
  }
  loadFocusEvents() {
    if (!this.useExternal) {
      this.el.addEventListener('focusout', this.onFocusOut);
    }
  }
  unloadFocusEvents() {
    this.el.removeEventListener('focusout', this.onFocusOut);
  }
  onValueUpdate(evt) {
    var _a;
    if (this.useExternal) {
      return;
    }
    this.pristine = false;
    const value = ((_a = evt.detail) !== null && _a !== void 0 ? _a : [])[0];
    if (Fe(value, this.value) && (this.errors.length === 0 || !!value)) {
      this.value = value;
      this.ymmcUpdate.emit({ type: R.Model, value });
    }
  }
  onValueChange(value) {
    this.updateErrors(false, this.touched, value);
  }
  updateErrors(pristine, touched, value) {
    this.errors = u4(pristine, touched, value) ? ['required'] : [];
  }
  onMakeDirty() {
    this.touched = true;
    this.pristine = false;
    this.updateErrors(false, this.touched, this.value);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-models-container", { answerId: this.answerId, code: this.code, isVehicleTrailer: this.isVehicleTrailer, modelOptions: this.modelOptions, questionGroupId: this.questionGroupId, selectedVehicle: this.selectedVehicle }));
  }
  convertModelsToChoices(models = {}) {
    const choices = [];
    for (const modelId of Object.keys(models)) {
      choices.push({ id: modelId, value: models[modelId] });
    }
    choices.sort((a, b) => a.value.localeCompare(b.value));
    return choices;
  }
  renderInternal() {
    var _a, _b;
    return ((((_a = this.selectedVehicle) === null || _a === void 0 ? void 0 : _a.makeId) || this.choices.length > 0) && (h("bp-sdk-vehicle-models", { answerId: this.answerId, code: this.code, errors: this.errors, isVehicleTrailer: this.isVehicleTrailer, label: "Enter vehicle model", models: this.filteredChoices, pristine: this.pristine, selectedModelId: (_b = this.selectedVehicle) === null || _b === void 0 ? void 0 : _b.modelId, touched: this.touched })));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroupId": ["onQuestionGroupIdChange"],
    "modelOptions": ["onModelsChange"],
    "selectedVehicle": ["onSelectionChange"],
    "filter": ["onFilterChange"],
    "choices": ["onChoicesChange"],
    "useExternal": ["onUseExternalChange"],
    "value": ["onValueChange"]
  }; }
};
BpSdkVehicleModelsContainer.style = bpSdkVehicleModelsContainerCss;

const bpSdkVehicleSaveButtonCss = "";

let BpSdkVehicleSaveButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Text to be displayed
     */
    this.text = '';
    /**
     * Id for button
     */
    this.buttonId = fx(8);
    /**
     * Controls disabled state of button
     */
    this.buttonDisabled = false;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-save-button');
    customElements.whenDefined('bp-sdk-external-vehicle-save-button').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-vehicle-save-button", { text: this.text, buttonId: this.buttonId, buttonDisabled: this.buttonDisabled });
  }
  renderInternal() {
    return (h("bp-sdk-button", { class: "bp-sdk-vehicle-save-button__container", text: this.text, buttonId: this.buttonId, buttonDisabled: this.buttonDisabled }));
  }
};
BpSdkVehicleSaveButton.style = bpSdkVehicleSaveButtonCss;

const bpSdkVehicleVinCss = "";

const VIN = {
  min: 17,
  max: 17,
  placeholder: 'VIN',
  type: 'vin',
};
const ConfigCode = 'mqs_vehicle_submodel';
let BpSdkVehicleVin = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Is searching
     */
    this.isSearching = false;
    /**
     * Should select configuration
     */
    this.shouldSelectConfiguration = false;
    /**
     * Is touched
     */
    this.touched = false;
    /**
     * Is pristine
     */
    this.pristine = true;
    /**
     * Error messages
     */
    this.errors = [];
    /**
     * Can Save
     */
    this.canSave = true;
    /**
     * Can search
     */
    this.canSearch = true;
    /**
     * Has result
     */
    this.hasResult = false;
    this.useExternal = false;
    this.labelId = fx(8);
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-vin');
    customElements.whenDefined('bp-sdk-external-vehicle-vin').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-vin", { answerId: this.answerId, canSave: this.canSave, canSearch: this.canSearch, code: this.code, errors: this.errors, errorText: this.errorText, hasResult: this.hasResult, isSearching: this.isSearching, label: this.label, labelId: this.labelId, questionGroupId: this.questionGroupId, pristine: this.pristine, shouldSelectConfiguration: this.shouldSelectConfiguration, touched: this.touched }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-vehicle-vin__container" }, h("div", { class: "bp-sdk-vehicle-vin__wrapper" }, h("bp-sdk-text-input", { answerId: this.answerId, code: this.code, errors: this.errors, errorText: this.errorText, fieldType: VIN.type, isEnabled: this.canSearch, label: this.label, labelId: this.labelId, max: VIN.max, min: VIN.min, placeholder: VIN.placeholder, pristine: this.pristine, questionId: this.labelId, touched: this.touched, text: this.value }), this.shouldSelectConfiguration && (h("bp-sdk-vehicle-configurations-container", { questionGroupId: this.questionGroupId, checkYmm: false, code: ConfigCode })))));
  }
};
BpSdkVehicleVin.style = bpSdkVehicleVinCss;

const bpSdkVehicleVinContainerCss = "";

let BpSdkVehicleVinContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.vinUpdate = createEvent(this, "vinUpdate", 7);
    this.ymmcUpdate = createEvent(this, "ymmcUpdate", 7);
    /**
     * VIN resource injected by redux
     */
    this.vinOptions = Object.assign({}, Ce);
    /**
     * VIN resource injected by redux
     */
    this.configurationOptions = {};
    /**
     * Selection resource injected by redux
     */
    this.vinStatus = i.NotLoaded;
    /**
     * Can Save
     */
    this.canSave = false;
    /**
     * Current value of answer
     */
    this.value = '';
    this.useExternal = false;
    this.touched = false;
    this.pristine = true;
    this.hasResult = false;
    this.isSearching = false;
    this.shouldSelectConfiguration = false;
    this.errors = [];
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { loadVin });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        config: getPartnerEngineConfig(state),
        configurationOptions: getVehicleOptionsConfigurations(state, this.questionGroupId),
        vinOptions: getVehicleOptionsVin(state, this.questionGroupId),
        vinStatus: getVinSelectionState(state, this.questionGroupId),
      };
    };
    this.onFocusOut = () => {
      this.touched = true;
      this.updateErrors(this.pristine, true, this.value);
    };
  }
  resetState() {
    this.touched = false;
    this.pristine = true;
    this.errors = [];
    this.errorText = undefined;
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-vin-container');
    customElements.whenDefined('bp-sdk-external-vehicle-vin-container').then(() => {
      this.useExternal = true;
    });
    this.onQuestionGroupIdChange();
  }
  onQuestionGroupIdChange() {
    this.handleSubscriptions();
  }
  onVinOptionsChange(vinOptions) {
    var _a;
    this.canSearch = (_a = vinOptions === null || vinOptions === void 0 ? void 0 : vinOptions.isAvailable) !== null && _a !== void 0 ? _a : true;
    this.lastResponse = vinOptions === null || vinOptions === void 0 ? void 0 : vinOptions.lastResponse;
  }
  onVinStatusChange(vinStatus) {
    this.vinResource = vinStatus !== null && vinStatus !== void 0 ? vinStatus : i.NotLoaded;
    this.isSearching = this.vinResource === i.Loading;
  }
  onConfigurationOptionsChange(configurationOptions) {
    const configs = configurationOptions !== null && configurationOptions !== void 0 ? configurationOptions : {};
    const keys = Object.keys(configs);
    this.hasResult = keys.length > 0;
    this.updateShouldSelectConfiguration(this.value, configurationOptions);
    if (keys.length === 1) {
      this.ymmcUpdate.emit({ type: R.Configuration, value: Object.keys(configurationOptions)[0] });
    }
  }
  loadFocusEvents() {
    if (!this.useExternal) {
      this.el.addEventListener('focusout', this.onFocusOut);
    }
  }
  unloadFocusEvents() {
    this.el.removeEventListener('focusout', this.onFocusOut);
  }
  componentDidLoad() {
    this.loadFocusEvents();
  }
  disconnectedCallback() {
    this.unloadFocusEvents();
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onValueChange(value) {
    this.updateShouldSelectConfiguration(value, this.configurationOptions);
  }
  updateShouldSelectConfiguration(vin, configurations) {
    // spread operator on configurations guards against null/undefined
    this.shouldSelectConfiguration = !!vin && Object.keys(Object.assign({}, configurations)).length > 1;
  }
  setVin(vin) {
    this.pristine = false;
    this.value = vin;
    this.updateErrors(this.pristine, this.touched, vin);
    const hasErrors = this.errors.length > 0 || this.errorText;
    const hasValidLength = VehicleVinService.hasValidLength(vin);
    this.canSave = !hasErrors && hasValidLength;
    if (!hasErrors) {
      if (hasValidLength) {
        this.loadVin({
          vin,
          config: this.config,
          questionGroupId: this.questionGroupId,
        });
      }
      this.vinUpdate.emit({ vin, answerId: this.answerId });
    }
  }
  onValueUpdate({ detail }) {
    if (this.useExternal) {
      return;
    }
    const vin = detail !== null && detail !== void 0 ? detail : '';
    if (Fe(this.value, vin)) {
      this.setVin(vin);
    }
  }
  updateErrors(pristine, touched, vin) {
    this.errors = u4(pristine, touched, vin) ? ['required'] : [];
    this.errorText = VehicleVinService.getValidationErrorMessage(vin);
  }
  onMakeDirty() {
    this.touched = true;
    this.pristine = false;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-vin-container", { answerId: this.answerId, code: this.code, canSave: this.canSave, canSearch: this.canSearch, config: this.config, configurationOptions: this.configurationOptions, questionGroupId: this.questionGroupId, value: this.value, vinOptions: this.vinOptions, vinStatus: this.vinStatus }));
  }
  renderInternal() {
    return (h("bp-sdk-vehicle-vin", { answerId: this.answerId, canSave: this.canSave, code: this.code, label: "Enter vehicle VIN", isSearching: this.isSearching, hasResult: this.hasResult, touched: this.touched, pristine: this.pristine, errors: this.errors, shouldSelectConfiguration: this.shouldSelectConfiguration, questionGroupId: this.questionGroupId, errorText: this.errorText, value: this.value }));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroupId": ["onQuestionGroupIdChange"],
    "vinOptions": ["onVinOptionsChange"],
    "vinStatus": ["onVinStatusChange"],
    "configurationOptions": ["onConfigurationOptionsChange"],
    "value": ["onValueChange"]
  }; }
};
BpSdkVehicleVinContainer.style = bpSdkVehicleVinContainerCss;

const bpSdkVehicleYearsCss = "";

let BpSdkVehicleYears = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Is pristine
     */
    this.pristine = true;
    /**
     * Is touched
     */
    this.touched = false;
    /**
     * Error messages
     */
    this.errors = [];
    /**
     * Year choices
     */
    this.years = [];
    /**
     * Is vehicle a trailer
     */
    this.isVehicleTrailer = false;
    this.fieldType = 'dropdown';
    this.inputComponentType = 'dropdown';
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-years');
    customElements.whenDefined('bp-sdk-external-vehicle-years').then(() => {
      this.useExternal = true;
    });
    this.onIsVehicleTrailerChange(this.isVehicleTrailer);
  }
  onIsVehicleTrailerChange(isTrailer) {
    this.fieldType = isTrailer ? 'vehicle' : 'dropdown';
    this.inputComponentType = isTrailer ? 'vehicle' : 'dropdown';
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-years", { answerId: this.answerId, code: this.code, errors: this.errors, isVehicleTrailer: this.isVehicleTrailer, label: this.label, pristine: this.pristine, selectedYear: this.selectedYear, touched: this.touched, years: this.years }));
  }
  renderInternal() {
    return (h("bp-sdk-dynamic-input-wrapper", { answerId: this.answerId, choiceId: this.selectedYear, choices: this.years, code: this.code, errors: this.errors, fieldType: this.fieldType, inputComponentType: this.inputComponentType, isAutocomplete: this.isVehicleTrailer, isLabelledField: true, isRequired: true, label: this.label, pristine: this.pristine, referenceType: "years", touched: this.touched }));
  }
  static get watchers() { return {
    "isVehicleTrailer": ["onIsVehicleTrailerChange"]
  }; }
};
BpSdkVehicleYears.style = bpSdkVehicleYearsCss;

const bpSdkVehicleYearsContainerCss = "";

let BpSdkVehicleYearsContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.ymmcUpdate = createEvent(this, "ymmcUpdate", 7);
    /**
     * IVehicleYearOptions injected by redux
     */
    this.yearOptions = {};
    /**
     * Is vehicle a trailer
     */
    this.isVehicleTrailer = false;
    this.choices = [];
    this.filteredChoices = [];
    this.useExternal = false;
    this.touched = false;
    this.pristine = true;
    this.errors = [];
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        store.mapDispatchToProps(this, {
          loadYears,
        });
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        config: getPartnerEngineConfig(state),
        yearOptions: getVehicleOptionsYears(state, this.questionGroupId),
        selectedVehicle: getVehicleOptionsSelection(state, this.questionGroupId),
      };
    };
    this.onFocusOut = () => {
      this.touched = true;
      this.updateErrors(this.pristine, true, this.value);
    };
  }
  resetState() {
    this.touched = false;
    this.pristine = true;
    this.value = undefined;
    this.errors = [];
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-years-container');
    customElements.whenDefined('bp-sdk-external-vehicle-years-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupIdChange();
  }
  fetchYears() {
    this.loadYears({ config: this.config, questionGroupId: this.questionGroupId });
  }
  onQuestionGroupIdChange() {
    this.handleSubscriptions();
  }
  onYearsChange(years) {
    if (years) {
      this.choices = this.convertYearsToChoices(years);
      this.updateValue(years, this.selectedVehicle);
    }
    else {
      this.fetchYears();
      this.updateValue(undefined, undefined);
    }
  }
  onVehicleSelectionChange(selection) {
    this.updateValue(this.yearOptions, selection);
  }
  updateValue(years, selection) {
    this.value = !!(years && (selection === null || selection === void 0 ? void 0 : selection.yearId) && years[selection.yearId]) ? years[selection.yearId].toString() : undefined;
  }
  onUseExternalChange(useExternal) {
    if (!useExternal) {
      this.unloadFocusEvents();
    }
  }
  loadFocusEvents() {
    if (!this.useExternal) {
      this.el.addEventListener('focusout', this.onFocusOut);
    }
  }
  unloadFocusEvents() {
    this.el.removeEventListener('focusout', this.onFocusOut);
  }
  componentDidLoad() {
    this.loadFocusEvents();
  }
  disconnectedCallback() {
    this.unloadFocusEvents();
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onFilterUpdate({ detail }) {
    var _a;
    this.filter = (_a = detail === null || detail === void 0 ? void 0 : detail.value) !== null && _a !== void 0 ? _a : '';
  }
  onFilterChange(filter) {
    this.updateChoices(this.choices, filter);
  }
  onChoicesChange(choices) {
    this.updateChoices(choices, this.filter);
  }
  updateChoices(choices, filter = '') {
    const regex = new RegExp(`.*${filter}.*`, 'gi');
    this.filteredChoices = choices.filter((choice) => !!choice.value.match(regex));
  }
  onValueUpdate(evt) {
    var _a;
    if (this.useExternal) {
      return;
    }
    this.pristine = false;
    const value = ((_a = evt.detail) !== null && _a !== void 0 ? _a : [])[0];
    const num = Number(value);
    const isNumber = !Number.isNaN(num);
    this.updateErrors(false, this.touched, value);
    if (this.errors.length === 0 && isNumber && Fe(value, this.value)) {
      this.value = value;
      this.ymmcUpdate.emit({ type: R.Year, value });
      this.filter = '';
    }
  }
  onValueChange(value) {
    this.updateErrors(false, this.touched, value);
  }
  updateErrors(pristine, touched, value) {
    this.errors = u4(pristine, touched, value) ? ['required'] : [];
  }
  onMakeDirty() {
    this.touched = true;
    this.pristine = false;
    this.updateErrors(false, this.touched, this.value);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-years-container", { answerId: this.answerId, code: this.code, config: this.config, isVehicleTrailer: this.isVehicleTrailer, questionGroupId: this.questionGroupId, selectedVehicle: this.selectedVehicle, yearOptions: this.yearOptions }));
  }
  convertYearsToChoices(years) {
    const choices = [];
    for (const year of Object.keys(years)) {
      choices.push({ id: year, value: year });
    }
    choices.sort((a, b) => parseFloat(b.value) - parseFloat(a.value));
    return choices;
  }
  renderInternal() {
    var _a, _b;
    return (this.choices.length > 0 && (h("bp-sdk-vehicle-years", { answerId: this.answerId, code: this.code, errors: this.errors, isVehicleTrailer: this.isVehicleTrailer, label: "Enter vehicle year", pristine: this.pristine, selectedYear: (_b = (_a = this.selectedVehicle) === null || _a === void 0 ? void 0 : _a.yearId) === null || _b === void 0 ? void 0 : _b.toString(), touched: this.touched, years: this.filteredChoices })));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroupId": ["onQuestionGroupIdChange"],
    "yearOptions": ["onYearsChange"],
    "selectedVehicle": ["onVehicleSelectionChange"],
    "useExternal": ["onUseExternalChange"],
    "filter": ["onFilterChange"],
    "choices": ["onChoicesChange"],
    "value": ["onValueChange"]
  }; }
};
BpSdkVehicleYearsContainer.style = bpSdkVehicleYearsContainerCss;

export { BpSdkAccordion as bp_sdk_accordion, BpSdkAccumulationQuestionGroupContainer as bp_sdk_accumulation_question_group_container, BpSdkAddressGroup as bp_sdk_address_group, BpSdkDriverQuestionPoolContainer as bp_sdk_driver_question_pool_container, BpSdkQuestionGroupContainer as bp_sdk_question_group_container, BpSdkStepperGroupContainer as bp_sdk_stepper_group_container, BpSdkVehicleDeleteButton as bp_sdk_vehicle_delete_button, BpSdkVehicleEditButton as bp_sdk_vehicle_edit_button, BpSdkVehicleInterface as bp_sdk_vehicle_interface, BpSdkVehicleMakes as bp_sdk_vehicle_makes, BpSdkVehicleMakesContainer as bp_sdk_vehicle_makes_container, BpSdkVehicleModels as bp_sdk_vehicle_models, BpSdkVehicleModelsContainer as bp_sdk_vehicle_models_container, BpSdkVehicleSaveButton as bp_sdk_vehicle_save_button, BpSdkVehicleVin as bp_sdk_vehicle_vin, BpSdkVehicleVinContainer as bp_sdk_vehicle_vin_container, BpSdkVehicleYears as bp_sdk_vehicle_years, BpSdkVehicleYearsContainer as bp_sdk_vehicle_years_container };
